@@ -30,7 +30,7 @@ from aws_cdk.core import Stack
 # stack: Stack
 
 triggers.TriggerFunction(stack, "MyTrigger",
-    runtime=lambda_.Runtime.NODEJS_12_X,
+    runtime=lambda_.Runtime.NODEJS_14_X,
     handler="index.handler",
     code=lambda_.Code.from_asset(__dirname + "/my-trigger")
 )
@@ -163,7 +163,9 @@ class _ITriggerProxy(
         :param scopes: A list of construct scopes which this trigger will depend on.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ITrigger.execute_after)
+            def stub(*scopes: constructs.Construct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "executeAfter", [*scopes]))
 
@@ -177,7 +179,9 @@ class _ITriggerProxy(
         :param scopes: A list of construct scopes which will take a dependency on this trigger.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ITrigger.execute_before)
+            def stub(*scopes: constructs.Construct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "executeBefore", [*scopes]))
 
@@ -235,7 +239,17 @@ class Trigger(
         :param execute_on_handler_change: Re-executes the trigger every time the handler changes. This implies that the trigger is associated with the ``currentVersion`` of the handler, which gets recreated every time the handler or its configuration is updated. Default: true
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Trigger.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                handler: aws_cdk.aws_lambda.Function,
+                execute_after: typing.Optional[typing.Sequence[constructs.Construct]] = None,
+                execute_before: typing.Optional[typing.Sequence[constructs.Construct]] = None,
+                execute_on_handler_change: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = TriggerProps(
@@ -257,7 +271,9 @@ class Trigger(
         :param scopes: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Trigger.execute_after)
+            def stub(*scopes: constructs.Construct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "executeAfter", [*scopes]))
 
@@ -271,7 +287,9 @@ class Trigger(
         :param scopes: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Trigger.execute_before)
+            def stub(*scopes: constructs.Construct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "executeBefore", [*scopes]))
 
@@ -295,7 +313,7 @@ class TriggerFunction(
         # stack: Stack
         
         triggers.TriggerFunction(stack, "MyTrigger",
-            runtime=lambda_.Runtime.NODEJS_12_X,
+            runtime=lambda_.Runtime.NODEJS_14_X,
             handler="index.handler",
             code=lambda_.Code.from_asset(__dirname + "/my-trigger")
         )
@@ -398,7 +416,56 @@ class TriggerFunction(
         :param retry_attempts: The maximum number of times to retry when the function returns an error. Minimum: 0 Maximum: 2 Default: 2
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(TriggerFunction.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                code: aws_cdk.aws_lambda.Code,
+                handler: builtins.str,
+                runtime: aws_cdk.aws_lambda.Runtime,
+                execute_after: typing.Optional[typing.Sequence[constructs.Construct]] = None,
+                execute_before: typing.Optional[typing.Sequence[constructs.Construct]] = None,
+                execute_on_handler_change: typing.Optional[builtins.bool] = None,
+                allow_all_outbound: typing.Optional[builtins.bool] = None,
+                allow_public_subnet: typing.Optional[builtins.bool] = None,
+                architecture: typing.Optional[aws_cdk.aws_lambda.Architecture] = None,
+                architectures: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.Architecture]] = None,
+                code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
+                current_version_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.VersionOptions, typing.Dict[str, typing.Any]]] = None,
+                dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
+                dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
+                dead_letter_topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+                description: typing.Optional[builtins.str] = None,
+                environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+                ephemeral_storage_size: typing.Optional[aws_cdk.core.Size] = None,
+                events: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.IEventSource]] = None,
+                filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
+                function_name: typing.Optional[builtins.str] = None,
+                initial_policy: typing.Optional[typing.Sequence[aws_cdk.aws_iam.PolicyStatement]] = None,
+                insights_version: typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion] = None,
+                layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
+                log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
+                log_retention_retry_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.LogRetentionRetryOptions, typing.Dict[str, typing.Any]]] = None,
+                log_retention_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                memory_size: typing.Optional[jsii.Number] = None,
+                profiling: typing.Optional[builtins.bool] = None,
+                profiling_group: typing.Optional[aws_cdk.aws_codeguruprofiler.IProfilingGroup] = None,
+                reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
+                security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
+                timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                tracing: typing.Optional[aws_cdk.aws_lambda.Tracing] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+                max_event_age: typing.Optional[aws_cdk.core.Duration] = None,
+                on_failure: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
+                on_success: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
+                retry_attempts: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = TriggerFunctionProps(
@@ -459,7 +526,9 @@ class TriggerFunction(
         :param scopes: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(TriggerFunction.execute_after)
+            def stub(*scopes: constructs.Construct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "executeAfter", [*scopes]))
 
@@ -473,7 +542,9 @@ class TriggerFunction(
         :param scopes: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(TriggerFunction.execute_before)
+            def stub(*scopes: constructs.Construct) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "executeBefore", [*scopes]))
 
@@ -537,7 +608,14 @@ class TriggerOptions:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(TriggerOptions.__init__)
+            def stub(
+                *,
+                execute_after: typing.Optional[typing.Sequence[constructs.Construct]] = None,
+                execute_before: typing.Optional[typing.Sequence[constructs.Construct]] = None,
+                execute_on_handler_change: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument execute_after", value=execute_after, expected_type=type_hints["execute_after"])
             check_type(argname="argument execute_before", value=execute_before, expected_type=type_hints["execute_before"])
             check_type(argname="argument execute_on_handler_change", value=execute_on_handler_change, expected_type=type_hints["execute_on_handler_change"])
@@ -648,7 +726,15 @@ class TriggerProps(TriggerOptions):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(TriggerProps.__init__)
+            def stub(
+                *,
+                execute_after: typing.Optional[typing.Sequence[constructs.Construct]] = None,
+                execute_before: typing.Optional[typing.Sequence[constructs.Construct]] = None,
+                execute_on_handler_change: typing.Optional[builtins.bool] = None,
+                handler: aws_cdk.aws_lambda.Function,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument execute_after", value=execute_after, expected_type=type_hints["execute_after"])
             check_type(argname="argument execute_before", value=execute_before, expected_type=type_hints["execute_before"])
             check_type(argname="argument execute_on_handler_change", value=execute_on_handler_change, expected_type=type_hints["execute_on_handler_change"])
@@ -874,7 +960,7 @@ class TriggerFunctionProps(aws_cdk.aws_lambda.FunctionProps, TriggerOptions):
             # stack: Stack
             
             triggers.TriggerFunction(stack, "MyTrigger",
-                runtime=lambda_.Runtime.NODEJS_12_X,
+                runtime=lambda_.Runtime.NODEJS_14_X,
                 handler="index.handler",
                 code=lambda_.Code.from_asset(__dirname + "/my-trigger")
             )
@@ -886,7 +972,54 @@ class TriggerFunctionProps(aws_cdk.aws_lambda.FunctionProps, TriggerOptions):
         if isinstance(vpc_subnets, dict):
             vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
         if __debug__:
-            type_hints = typing.get_type_hints(TriggerFunctionProps.__init__)
+            def stub(
+                *,
+                max_event_age: typing.Optional[aws_cdk.core.Duration] = None,
+                on_failure: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
+                on_success: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
+                retry_attempts: typing.Optional[jsii.Number] = None,
+                allow_all_outbound: typing.Optional[builtins.bool] = None,
+                allow_public_subnet: typing.Optional[builtins.bool] = None,
+                architecture: typing.Optional[aws_cdk.aws_lambda.Architecture] = None,
+                architectures: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.Architecture]] = None,
+                code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
+                current_version_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.VersionOptions, typing.Dict[str, typing.Any]]] = None,
+                dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
+                dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
+                dead_letter_topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
+                description: typing.Optional[builtins.str] = None,
+                environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+                ephemeral_storage_size: typing.Optional[aws_cdk.core.Size] = None,
+                events: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.IEventSource]] = None,
+                filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
+                function_name: typing.Optional[builtins.str] = None,
+                initial_policy: typing.Optional[typing.Sequence[aws_cdk.aws_iam.PolicyStatement]] = None,
+                insights_version: typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion] = None,
+                layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
+                log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
+                log_retention_retry_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.LogRetentionRetryOptions, typing.Dict[str, typing.Any]]] = None,
+                log_retention_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                memory_size: typing.Optional[jsii.Number] = None,
+                profiling: typing.Optional[builtins.bool] = None,
+                profiling_group: typing.Optional[aws_cdk.aws_codeguruprofiler.IProfilingGroup] = None,
+                reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
+                security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
+                timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                tracing: typing.Optional[aws_cdk.aws_lambda.Tracing] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+                code: aws_cdk.aws_lambda.Code,
+                handler: builtins.str,
+                runtime: aws_cdk.aws_lambda.Runtime,
+                execute_after: typing.Optional[typing.Sequence[constructs.Construct]] = None,
+                execute_before: typing.Optional[typing.Sequence[constructs.Construct]] = None,
+                execute_on_handler_change: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument max_event_age", value=max_event_age, expected_type=type_hints["max_event_age"])
             check_type(argname="argument on_failure", value=on_failure, expected_type=type_hints["on_failure"])
             check_type(argname="argument on_success", value=on_success, expected_type=type_hints["on_success"])
